@@ -1,6 +1,6 @@
 """Module for the automations and business logic of XKNX."""
 # flake8: noqa
-from .stateupdater import StateUpdater
-from .telegram_queue import TelegramQueue
 from .config import Config
+from .state_updater import StateUpdater
+from .telegram_queue import TelegramQueue
 from .value_reader import ValueReader
