@@ -29,6 +29,7 @@ class ConnectionStateRequest(KNXIPBody):
 
     def from_knx(self, raw):
         """Parse/deserialize from KNX/IP raw data."""
+
         def info_from_knx(info):
             """Parse info bytes."""
             if len(info) < 2:
@@ -36,18 +37,21 @@ class ConnectionStateRequest(KNXIPBody):
             self.communication_channel_id = info[0]
             # info[1] is reserved
             return 2
+
         pos = info_from_knx(raw)
         pos += self.control_endpoint.from_knx(raw[pos:])
         return pos
 
     def to_knx(self):
         """Serialize to KNX/IP raw data."""
+
         def info_to_knx():
             """Serialize information bytes."""
             info = []
             info.append(self.communication_channel_id)
             info.append(0x00)  # Reserved
             return info
+
         data = []
         data.extend(info_to_knx())
         data.extend(self.control_endpoint.to_knx())
@@ -55,7 +59,9 @@ class ConnectionStateRequest(KNXIPBody):
 
     def __str__(self):
         """Return object as readable string."""
-        return '<ConnectionStateRequest CommunicationChannelID="{0}", ' \
-            'control_endpoint="{1}" />'.format(
-                self.communication_channel_id,
-                self.control_endpoint)
+        return (
+            '<ConnectionStateRequest CommunicationChannelID="{}", '
+            'control_endpoint="{}" />'.format(
+                self.communication_channel_id, self.control_endpoint
+            )
+        )
