@@ -13,34 +13,41 @@ from .remote_value import RemoteValue
 class RemoteValueSensor(RemoteValue):
     """Abstraction for many different sensor DPT types."""
 
-    def __init__(self,
-                 xknx,
-                 group_address=None,
-                 group_address_state=None,
-                 sync_state=True,
-                 value_type=None,
-                 device_name=None,
-                 feature_name="Value",
-                 after_update_cb=None):
+    def __init__(
+        self,
+        xknx,
+        group_address=None,
+        group_address_state=None,
+        sync_state=True,
+        value_type=None,
+        device_name=None,
+        feature_name="Value",
+        after_update_cb=None,
+    ):
         """Initialize RemoteValueSensor class."""
         # pylint: disable=too-many-arguments
         _dpt_class = DPTBase.parse_transcoder(value_type)
         if _dpt_class is None:
-            raise ConversionError("invalid value type", value_type=value_type, device_name=device_name)
+            raise ConversionError(
+                "invalid value type", value_type=value_type, device_name=device_name
+            )
         self.dpt_class = _dpt_class
-        super().__init__(xknx,
-                         group_address,
-                         group_address_state,
-                         sync_state=sync_state,
-                         device_name=device_name,
-                         feature_name=feature_name,
-                         after_update_cb=after_update_cb)
+        super().__init__(
+            xknx,
+            group_address,
+            group_address_state,
+            sync_state=sync_state,
+            device_name=device_name,
+            feature_name=feature_name,
+            after_update_cb=after_update_cb,
+        )
 
     def payload_valid(self, payload):
         """Test if telegram payload may be parsed."""
         return (
-            isinstance(payload, DPTArray) and
-            len(payload.value) == self.dpt_class.payload_length)
+            isinstance(payload, DPTArray)
+            and len(payload.value) == self.dpt_class.payload_length
+        )
 
     def to_knx(self, value):
         """Convert value to payload."""
@@ -58,6 +65,4 @@ class RemoteValueSensor(RemoteValue):
     @property
     def ha_device_class(self):
         """Return a string representing the home assistant device class."""
-        if hasattr(self.dpt_class, 'ha_device_class'):
-            return self.dpt_class.ha_device_class
-        return None
+        return getattr(self.dpt_class, "ha_device_class", None)
